@@ -1,6 +1,7 @@
 """jc - JSON Convert `foo` command output streaming parser
 
-> This streaming parser outputs JSON Lines
+> This streaming parser outputs JSON Lines (cli) or returns an Iterable of
+> Dictionaries (module)
 
 <<Short foo description and caveats>>
 
@@ -11,32 +12,22 @@ Usage (cli):
 Usage (module):
 
     import jc
-    # result is an iterable object (generator)
+
     result = jc.parse('foo_s', foo_command_output.splitlines())
     for item in result:
         # do something
 
-    or
-
-    import jc.parsers.foo_s
-    # result is an iterable object (generator)
-    result = jc.parsers.foo_s.parse(foo_command_output.splitlines())
-    for item in result:
-        # do something
-
 Schema:
 
     {
       "foo":            string,
 
-      # Below object only exists if using -qq or ignore_exceptions=True
-
-      "_jc_meta":
-        {
-          "success":    boolean,     # false if error parsing
-          "error":      string,      # exists if "success" is false
-          "line":       string       # exists if "success" is false
-        }
+      # below object only exists if using -qq or ignore_exceptions=True
+      "_jc_meta": {
+        "success":      boolean,     # false if error parsing
+        "error":        string,      # exists if "success" is false
+        "line":         string       # exists if "success" is false
+      }
     }
 
 Examples:
@@ -101,7 +92,7 @@ def parse(
     ignore_exceptions: bool = False
 ) -> Union[Iterable[Dict], tuple]:
     """
-    Main text parsing generator function. Returns an iterator object.
+    Main text parsing generator function. Returns an iterable object.
 
     Parameters:
 
@@ -112,13 +103,10 @@ def parse(
         quiet:             (boolean)   suppress warning messages if True
         ignore_exceptions: (boolean)   ignore parsing exceptions if True
 
-    Yields:
-
-        Dictionary. Raw or processed structured data.
 
     Returns:
 
-        Iterator object (generator)
+        Iterable of Dictionaries
     """
     jc.utils.compatibility(__name__, info.compatible, quiet)
     streaming_input_type_check(data)
