@@ -10,7 +10,7 @@ Usage (cli):
 
     $ upower -d | jc --upower
 
-    or
+or
 
     $ jc upower -d
 
@@ -19,11 +19,6 @@ Usage (module):
     import jc
     result = jc.parse('upower', upower_command_output)
 
-    or
-
-    import jc.parsers.upower
-    result = jc.parsers.upower.parse(upower_command_output)
-
 Schema:
 
     [
